TODO
====

- add tests
- fix memory handling
- check files/directories exist
- validate input file


Eventually
----------

- add project_id support (not needed for apollo)


Done
----

- ~add ORCA libraries~
- ~add --resubmit flag~
- ~add scratch directory support~
